@@ -21,7 +21,7 @@ class VprikolAPI:
         result = await get(url=f'{self.base_url}ip', headers=self.headers, params={'ip': ip})
 
         if not result.success:
-            raise Exception(result.error)
+            return result
 
         return IpAPIResponse(**result.data)
 
@@ -29,7 +29,7 @@ class VprikolAPI:
         result = await get(url=f'{self.base_url}members', headers=self.headers, params={'server': server_id,
                                                                                           'fraction_id': fraction_id})
         if not result.success:
-            raise Exception(result.error)
+            return result
 
         players = []
         for player in result.data['players']:
@@ -46,16 +46,20 @@ class VprikolAPI:
         task = await post(url=f'{self.base_url}find/createTask', headers=self.headers,
                           params={'server': server_id, 'nick': nickname})
         if not task.success:
-            raise Exception(task.error)
+            return task
 
         task = CreatedFindTaskAPIResponse(**task.data)
         while True:
             await asyncio.sleep(1)
             result = await get(url=f'{self.base_url}find/getTaskResult', headers=self.headers,
                                params={'request_id': task.request_id})
+
             if not result.success and result.error.error_code and result.error.error_code == 425:
                 continue
 
+            if result.error and result.error.error_code == 422 :
+                return result
+
             try:
                 return PlayerInfoArizonaAPIResponse(**result.data)
             except ValidationError:
@@ -72,7 +76,7 @@ class VprikolAPI:
                            params=params)
 
         if not result.success:
-            raise Exception(result.error)
+            return result
 
         if isinstance(result.data, list):
             return parse_obj_as(list[ServerStatusAPIResponse], result.data)
@@ -88,7 +92,7 @@ class VprikolAPI:
                            params=params)
 
         if not result.success:
-            raise Exception(result.error)
+            return result
 
         return RatingAPIResponse(**result.data)
 
@@ -97,7 +101,7 @@ class VprikolAPI:
                            params={'nick': nickname})
 
         if not result.success:
-            raise Exception(result.error)
+            return result
 
         return CheckRPUsernameAPIResponse(**result.data)
 
@@ -107,6 +111,6 @@ class VprikolAPI:
         result = await get(url=f'{self.base_url}rpnick', headers=self.headers,
                            params={'gender': gender, 'nation': nation})
         if not result.success:
-            raise Exception(result.error)
+            return result
 
         return GenerateRPUsernameAPIResponse(**result.data)
